<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Uspješna ovjera</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspjela ovjera, preostala je samo jedna prilika</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Ovjerite vaš otisak prsta</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Uspješna ovjera</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspjela ovjera, preostala je samo jedna prilika</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Otisak prsta je zaključan, molim koristite lozinku</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Uspješna ovjera</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspjela ovjera, preostala je samo jedna prilika</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Uspješna ovjera</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspjela ovjera, preostala je samo jedna prilika</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Pogrešna lozinka</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lozinka</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Molim pokušajte ponovno nakon jedne minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zaboravili ste lozinku?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Molim pokušajte ponovno nakon jedne minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zaboravili ste lozinku?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Uspješna ovjera</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Neuspjela ovjera, preostala je samo jedna prilika</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Pogrešni PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Unesite vaš PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Molim pokušajte ponovno nakon jedne minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Račun</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Lozink je istekla, molim promijenite je</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Pogrešni račun</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Pogrešna lozinka</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Zaključaj zaslon</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Neuspjelo zaključavanje zaslona</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Isteklo je vrijeme ovjere otiska prsta, molim unesite lozinku ručno</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Neuspjelo podudaranje otiska prsta</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Gornji korisnici su još prijavljeni i podaci će biti izgubljeni zbog isključivanja računala, jeste li sigurni da želite isključiti računalo?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Gornji korisnici su još prijavljeni i podaci će biti izgubljeni zbog ponovnog podizanja sustava, jeste li sigurni da želite ponovno podići sustav?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberniraj</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zaključaj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Promjeni korisnika</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Promijeni sustav</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Ovi programi sprečavaju isključivanje računala, a prisilno isključivanje može uzrokovati gubitak podataka. </translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Za zatvaranje programa kliknite Otkaži i zatim zatvorite program.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Ovi programi sprečavaju ponovno pokretanje računala, a prisilno ponovno pokretanje može uzrokovati gubitak podataka.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Ovi programi sprečavaju odjavu računala, a prisilno odjavljivanje može uzrokovati gubitak podataka.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberniraj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Jeste li sigurni da želite isključiti?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Jeste li sigurni da želite ponovno podignuti sustav?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Jeste li sigurni da se želite odjaviti?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Uključi</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Isključi</translation>
    </message>
</context>
</TS>